@@ -1,9 +1,11 @@
 # __init__.py
+from shrinemaiden.augmentor import ImageAugmentor
 import shrinemaiden.transcript
 import shrinemaiden.transcript_class
 import shrinemaiden.train
-import shrinemaiden.utils
+import shrinemaiden.util
 import shrinemaiden.charmap
+import shrinemaiden.augmentor
 
 # Version of the package
-__version__ = "0.2.3"
+__version__ = "0.3.0"
